@@ -429,7 +429,9 @@ def warp_ndarray(ndarray, in_gt, in_prj=None, out_prj=None, out_dtype=None,
     #    in_ds.SetMetadata(rpc, "RPC")
     #    transformerOptions = ['RPC_DEM=data/warp_52_dem.tif']
 
-    if CPUs is None or CPUs > 1:
+    # use GDALs multiprocessing as long as the current process is not a child process of a multiprocessing main process
+    # - otherwise, gdal.Warp() hangs with GDAL versions from 3.2.1 and above (does not allow sub-multiprocessing)
+    if (CPUs is None or CPUs > 1) and multiprocessing.current_process().name == 'MainProcess':
         gdal.SetConfigOption('GDAL_NUM_THREADS', str(CPUs if CPUs else multiprocessing.cpu_count()))
 
         # gdal.SetConfigOption('GDAL_CACHEMAX', str(800))
